package com.example.demo.controllers

import com.example.demo.entities.User
import com.example.demo.repositories.UserRepository
import jakarta.validation.Valid
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.HttpStatus
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*

@RestController
class UsersController {
    @Autowired
    lateinit var repo: UserRepository

    @GetMapping("/users")
    fun index(): MutableIterable<User> {
        return repo.findAll()
    }

    @GetMapping("/users/{id}")
    fun show(@PathVariable id: Long): User? {
        return repo.findById(id).get()
    }

    @PostMapping("/users")
    fun create(@Valid @RequestBody newUser: User): ResponseEntity<User> {
        val user = repo.save(newUser)
        return ResponseEntity(user, HttpStatus.CREATED)
    }

    @PatchMapping("/users/{id}")
    fun update(@PathVariable id: Long, @Valid @RequestBody user: User): ResponseEntity<User> {
        user.id = id
        return ResponseEntity(repo.save(user), HttpStatus.OK)
    }

    @DeleteMapping("/users/{id}")
    fun destroy(@PathVariable id: Long) {
        return repo.deleteById(id)
    }
}
